@@ -20,17 +20,22 @@
         <translation type="obsolete">Behälter</translation>
     </message>
     <message>
-        <location filename="../src/cachewindow.cpp" line="263"/>
+        <location filename="../src/cachewindow.cpp" line="241"/>
         <source>Description</source>
         <translation>Beschreibung</translation>
     </message>
     <message>
-        <location filename="../src/cachewindow.cpp" line="272"/>
+        <location filename="../src/cachewindow.cpp" line="251"/>
+        <source>Navigation</source>
+        <translation>Navigation</translation>
+    </message>
+    <message>
+        <location filename="../src/cachewindow.cpp" line="261"/>
         <source>Hint</source>
         <translation>Hinweis</translation>
     </message>
     <message>
-        <location filename="../src/cachewindow.cpp" line="281"/>
+        <location filename="../src/cachewindow.cpp" line="271"/>
         <source>Open in browser</source>
         <translation>Im Browser öffnen</translation>
     </message>
@@ -56,7 +61,7 @@
 <context>
     <name>GcLive</name>
     <message>
-        <location filename="../plugins/cacheprovider/gclive/gclive.cpp" line="87"/>
+        <location filename="../plugins/cacheprovider/gclive/gclive.cpp" line="89"/>
         <source>No valid login specified, cache positions will be inaccurate!</source>
         <translation>Kein gültiger Login angegeben, Cache-Positionen werden ungenau sein!</translation>
     </message>
@@ -65,23 +70,23 @@
         <translation type="obsolete">Einloggen erfolgreich!</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gclive/gclive.cpp" line="199"/>
+        <location filename="../plugins/cacheprovider/gclive/gclive.cpp" line="200"/>
         <source>Login failed!</source>
         <translation>Einloggen fehlgeschlagen!</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gclive/gclive.cpp" line="294"/>
+        <location filename="../plugins/cacheprovider/gclive/gclive.cpp" line="298"/>
         <source>Unable to determine cache id!</source>
         <translation>Cache-ID nicht feststellbar!</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gclive/gclive.cpp" line="319"/>
+        <location filename="../plugins/cacheprovider/gclive/gclive.cpp" line="323"/>
         <source>Unable to determine cache guid!</source>
         <translation>Cache-Guid nicht feststellbar!</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gclive/gclive.cpp" line="344"/>
-        <location filename="../plugins/cacheprovider/gclive/gclive.cpp" line="351"/>
+        <location filename="../plugins/cacheprovider/gclive/gclive.cpp" line="349"/>
+        <location filename="../plugins/cacheprovider/gclive/gclive.cpp" line="356"/>
         <source>GcLive</source>
         <translation></translation>
     </message>
@@ -108,7 +113,14 @@
 <context>
     <name>HintDialog</name>
     <message>
-        <location filename="../src/cachewindow.cpp" line="25"/>
+        <source>Hint</source>
+        <translation type="obsolete">Hinweis</translation>
+    </message>
+</context>
+<context>
+    <name>HintWindow</name>
+    <message>
+        <location filename="../src/cachewindow.cpp" line="23"/>
         <source>Hint</source>
         <translation>Hinweis</translation>
     </message>
@@ -116,70 +128,70 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../src/mainwindow.cpp" line="25"/>
+        <location filename="../src/mainwindow.cpp" line="28"/>
         <source>&amp;File</source>
         <translation>&amp;Datei</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="26"/>
+        <location filename="../src/mainwindow.cpp" line="29"/>
         <source>E&amp;xit</source>
         <translation>B&amp;eenden</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="33"/>
+        <location filename="../src/mainwindow.cpp" line="36"/>
         <source>&amp;Map</source>
         <translation>&amp;Karte</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="34"/>
+        <location filename="../src/mainwindow.cpp" line="37"/>
         <source>Map &amp;Settings</source>
         <translation>&amp;Karteneinstellungen</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="39"/>
+        <location filename="../src/mainwindow.cpp" line="42"/>
         <source>&amp;Plugins</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="43"/>
+        <location filename="../src/mainwindow.cpp" line="46"/>
         <source>&amp;Help</source>
         <translation>&amp;Hilfe</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="44"/>
+        <location filename="../src/mainwindow.cpp" line="47"/>
         <source>&amp;About</source>
         <translation>&amp;Über</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="58"/>
+        <location filename="../src/mainwindow.cpp" line="61"/>
         <source>About CacheMe</source>
         <translation>Über CacheMe</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="59"/>
-        <location filename="../src/mainwindow.cpp" line="73"/>
+        <location filename="../src/mainwindow.cpp" line="62"/>
+        <location filename="../src/mainwindow.cpp" line="76"/>
         <source>CacheMe</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="59"/>
+        <location filename="../src/mainwindow.cpp" line="62"/>
         <source>Version</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="60"/>
+        <location filename="../src/mainwindow.cpp" line="63"/>
         <source>Build date:</source>
         <translation>Erstellungsdatum:</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="61"/>
+        <location filename="../src/mainwindow.cpp" line="64"/>
         <source>(c) 2011 by Till Harbaum &lt;till@harbaum.org&gt;</source>
         <oldsource>(c) 2011 by Till Harbaum &lt;till@harbaum.org&gt;
 </oldsource>
         <translation>(c) 2011 von Till Harbaum &lt;till@harbaum.org&gt;</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="62"/>
+        <location filename="../src/mainwindow.cpp" line="65"/>
         <source>CacheMe is an online geocaching application.</source>
         <translation>CacheMe ist eine Online-Geocaching-Anwendung.</translation>
     </message>
@@ -248,6 +260,69 @@
         <translation type="obsolete">Öffne &quot;%1&quot; im Browser ...</translation>
     </message>
 </context>
+<context>
+    <name>NavigationWindow</name>
+    <message>
+        <location filename="../src/navigationwindow.cpp" line="57"/>
+        <source>Distance</source>
+        <translation>Entfernung</translation>
+    </message>
+    <message>
+        <source>Current coordinate:</source>
+        <translation type="obsolete">Aktuelle Koordinate:</translation>
+    </message>
+    <message>
+        <location filename="../src/navigationwindow.cpp" line="67"/>
+        <location filename="../src/navigationwindow.cpp" line="77"/>
+        <source>Latitude</source>
+        <translation>Breite</translation>
+    </message>
+    <message>
+        <location filename="../src/navigationwindow.cpp" line="69"/>
+        <location filename="../src/navigationwindow.cpp" line="79"/>
+        <source>Longitude</source>
+        <translation>Länge</translation>
+    </message>
+    <message>
+        <source>Cache coordinate:</source>
+        <translation type="obsolete">Cache-Koordinate:</translation>
+    </message>
+    <message>
+        <location filename="../src/navigationwindow.cpp" line="43"/>
+        <source>Navigation</source>
+        <translation>Navigation</translation>
+    </message>
+    <message>
+        <location filename="../src/navigationwindow.cpp" line="65"/>
+        <source>Current coordinate</source>
+        <translation>Aktuelle Koordinate</translation>
+    </message>
+    <message>
+        <location filename="../src/navigationwindow.cpp" line="75"/>
+        <source>Cache coordinate</source>
+        <translation>Cache-Koordinate</translation>
+    </message>
+    <message>
+        <location filename="../src/navigationwindow.cpp" line="124"/>
+        <source>S</source>
+        <translation>S</translation>
+    </message>
+    <message>
+        <location filename="../src/navigationwindow.cpp" line="125"/>
+        <source>N</source>
+        <translation>N</translation>
+    </message>
+    <message>
+        <location filename="../src/navigationwindow.cpp" line="141"/>
+        <source>W</source>
+        <translation>W</translation>
+    </message>
+    <message>
+        <location filename="../src/navigationwindow.cpp" line="142"/>
+        <source>E</source>
+        <translation>O</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
