@@ -5,6 +5,7 @@
 
 #include <QQueue>
 #include <QDir>
+#include <QVBoxLayout>
 
 #include "cacheproviderplugin.h"
 
@@ -19,8 +20,8 @@ class CacheProvider  : public QObject {
   void requestDetail(const QString &);
   void next();
   void done();
-  void createMenu(QMenu *);
   void start();
+  void pluginConfig(QDialog *, QVBoxLayout *);
 
   // functions redirected at current plugin
   QString name();
