@@ -5,7 +5,7 @@
 
 #include "mainwindow.h"
 #include "mapwidget.h"
-#include "mapdialog.h"
+#include "settingsdialog.h"
 #include "iconloader.h"  
 #include "cachewindow.h"
 
@@ -33,16 +33,12 @@ void MainWindow::createMenu() {
   menuBar()->addMenu(menu);
 #endif
   
-  menu = new QMenu(tr("&Map"), this);
-  action = new QAction(tr("Map &Settings"), this);
-  connect(action, SIGNAL(triggered()), this, SLOT(mapdialog()));
+  menu = new QMenu(tr("&Settings"), this);
+  action = new QAction(tr("&Settings"), this);
+  connect(action, SIGNAL(triggered()), this, SLOT(settingsdialog()));
   menu->addAction(action);
   menuBar()->addMenu(menu);
 
-  menu = new QMenu(tr("&Plugins"), this);
-  m_cacheProvider->createMenu(menu);
-  menuBar()->addMenu(menu);
-
   menu = new QMenu(tr("&Help"), this);
   action = new QAction(tr("&About"), this);
   connect(action, SIGNAL(triggered()), this, SLOT(about()));
@@ -50,10 +46,10 @@ void MainWindow::createMenu() {
   menuBar()->addMenu(menu);
 }
 
-void MainWindow::mapdialog() {
+void MainWindow::settingsdialog() {
   qDebug() << __FUNCTION__;
 
-  MapDialog dialog(m_mapWidget, this);
+  SettingsDialog dialog(m_mapWidget, m_cacheProvider, this);
   dialog.exec(); 
 }
 
@@ -167,8 +163,8 @@ MainWindow::~MainWindow() {
 }
 
 void MainWindow::resizeEvent(QResizeEvent*) {
-  m_view->setSceneRect(QRectF(QPointF(0.0, 0.0), m_view->size()));
-  m_mapWidget->resize(m_view->size());
+  m_view->setSceneRect(QRect(QPoint(0,0), m_view->contentsRect().size()));
+  m_mapWidget->resize(m_view->contentsRect().size());
 }
 
 void MainWindow::selectCache(const QString &name) {
@@ -210,7 +206,7 @@ void MainWindow::displayError(const QString &message) {
 void MainWindow::showDetail(const Cache &cache) {
   qDebug() << __FUNCTION__;
 
-  CacheWindow *cacheWindow = new CacheWindow(cache, this);
+  CacheWindow *cacheWindow = new CacheWindow(cache, m_locationProvider, this);
   cacheWindow->show();
 }
 
@@ -229,7 +225,7 @@ void MainWindow::setBusy(bool on) {
       progressBar->setMaximum(0);
       progressBar->setValue(25);
       progressBar->setMaximumWidth(128);
-      progressBar->setMaximumHeight(16);
+      progressBar->setMaximumHeight(14);  // seems to be useful
       statusBar()->addPermanentWidget(progressBar);
     } else {
       statusBar()->addPermanentWidget(progressBar);
